From: "Rafael J. Wysocki" <rjw@rjwysocki.net>
To: Linux ACPI <linux-acpi@vger.kernel.org>
Cc: LKML <linux-kernel@vger.kernel.org>, Bob Moore <robert.moore@intel.com>
Subject: [PATCH 12/20] ACPICA: executer/exsystem: Add units to time variable names
Date: Mon, 11 Apr 2022 20:57:02 +0200 [thread overview]
Message-ID: <8110555.NyiUUSuA9g@kreacher> (raw)
In-Reply-To: <5578328.DvuYhMxLoT@kreacher>
From: Paul Menzel <pmenzel@molgen.mpg.de>
ACPICA commit b69cbef7a83eadb102a1ff6c6f6fc5abce34805a
`how_long` refers to different units in both functions, so make it more
clear, what unit they expect. That also makes one comment superfluous.
Link: https://github.com/acpica/acpica/commit/b69cbef7
Signed-off-by: Bob Moore <robert.moore@intel.com>
Signed-off-by: Rafael J. Wysocki <rafael.j.wysocki@intel.com>
---
exsystem.c | 22 +++++++++++-----------
1 file changed, 11 insertions(+), 11 deletions(-)
diff -Nurp linux.before_name/drivers/acpi/acpica/exsystem.c linux.after_name/drivers/acpi/acpica/exsystem.c
--- linux.before_name/drivers/acpi/acpica/exsystem.c 2022-04-01 18:26:24.556426955 +0200
+++ linux.after_name/drivers/acpi/acpica/exsystem.c 2022-04-01 18:26:20.646475824 +0200
@@ -107,7 +107,7 @@ acpi_status acpi_ex_system_wait_mutex(ac
*
* FUNCTION: acpi_ex_system_do_stall
*
* PARAMETERS: how_long - The amount of time to stall,
* in microseconds
*
* RETURN: Status
@@ -120,24 +120,24 @@ acpi_status acpi_ex_system_wait_mutex(ac
*
******************************************************************************/
-acpi_status acpi_ex_system_do_stall(u32 how_long)
+acpi_status acpi_ex_system_do_stall(u32 how_long_us)
{
acpi_status status = AE_OK;
ACPI_FUNCTION_ENTRY();
- if (how_long > 255) { /* 255 microseconds */
+ if (how_long_us > 255) {
/*
- * Longer than 255 usec, this is an error
+ * Longer than 255 microseconds, this is an error
*
* (ACPI specifies 100 usec as max, but this gives some slack in
* order to support existing BIOSs)
*/
ACPI_ERROR((AE_INFO,
- "Time parameter is too large (%u)", how_long));
+ "Time parameter is too large (%u)", how_long_us));
status = AE_AML_OPERAND_VALUE;
} else {
- acpi_os_stall(how_long);
+ acpi_os_stall(how_long_us);
}
return (status);
@@ -147,7 +147,7 @@ acpi_status acpi_ex_system_do_stall(u32
*
* FUNCTION: acpi_ex_system_do_sleep
*
* PARAMETERS: how_long - The amount of time to sleep,
* in milliseconds
*
* RETURN: None
@@ -156,7 +156,7 @@ acpi_status acpi_ex_system_do_stall(u32
*
******************************************************************************/
-acpi_status acpi_ex_system_do_sleep(u64 how_long)
+acpi_status acpi_ex_system_do_sleep(u64 how_long_ms)
{
ACPI_FUNCTION_ENTRY();
@@ -168,11 +168,11 @@ acpi_status acpi_ex_system_do_sleep(u64
* For compatibility with other ACPI implementations and to prevent
* accidental deep sleeps, limit the sleep time to something reasonable.
*/
- if (how_long > ACPI_MAX_SLEEP) {
- how_long = ACPI_MAX_SLEEP;
+ if (how_long_ms > ACPI_MAX_SLEEP) {
+ how_long_ms = ACPI_MAX_SLEEP;
}
- acpi_os_sleep(how_long);
+ acpi_os_sleep(how_long_ms);
/* And now we must get the interpreter again */
next prev parent reply other threads:[~2022-04-11 19:05 UTC|newest]
Thread overview: 27+ messages / expand[flat|nested] mbox.gz Atom feed top
2022-04-11 18:46 [PATCH 00/20] ACPICA: ACPICA 20220331 Rafael J. Wysocki
2022-04-11 18:47 ` [PATCH 01/20] ACPICA: Add support for the Windows 11 _OSI string Rafael J. Wysocki
2022-04-11 18:47 ` [PATCH 02/20] ACPICA: Add the subtable CFMWS to the CEDT table Rafael J. Wysocki
2022-04-11 18:48 ` [PATCH 03/20] ACPICA: iASL: NHLT: Treat Terminator as specific_config Rafael J. Wysocki
2022-04-11 18:49 ` [PATCH 04/20] ACPICA: iASL: NHLT: Fix parsing undocumented bytes at the end of Endpoint Descriptor Rafael J. Wysocki
2022-04-11 18:50 ` [PATCH 05/20] ACPICA: iASL: NHLT: Rename linux specific strucures to device_info Rafael J. Wysocki
2022-04-11 18:51 ` [PATCH 06/20] ACPICA: Add new ACPI 6.4 semantics to the Load() operator Rafael J. Wysocki
2022-04-11 18:52 ` [PATCH 07/20] ACPICA: Add new ACPI 6.4 semantics for LoadTable() operator Rafael J. Wysocki
2022-04-11 18:53 ` [PATCH 08/20] ACPICA: Clean up double word in comment Rafael J. Wysocki
2022-04-11 18:54 ` [PATCH 09/20] ACPICA: Update copyright notices to the year 2022 Rafael J. Wysocki
2022-04-11 18:55 ` [PATCH 10/20] ACPICA: Removed some tabs and // comments Rafael J. Wysocki
2022-04-11 18:56 ` [PATCH 11/20] ACPICA: Headers: Replace zero-length array with flexible-array member Rafael J. Wysocki
2022-04-11 18:57 ` Rafael J. Wysocki [this message]
2022-04-11 18:58 ` [PATCH 13/20] ACPICA: Add support for ARM Performance Monitoring Unit Table Rafael J. Wysocki
2022-04-11 18:59 ` [PATCH 14/20] ACPICA: executer/exsystem: Inform users about ACPI spec violation Rafael J. Wysocki
2022-04-12 2:53 ` kernel test robot
2022-04-12 12:47 ` Rafael J. Wysocki
2022-04-11 18:59 ` [PATCH 15/20] ACPICA: executer/exsystem: Warn about sleeps greater than 10 ms Rafael J. Wysocki
2022-04-12 5:22 ` kernel test robot
2022-05-21 16:11 ` Rafael J. Wysocki
2022-05-21 23:28 ` Paul Menzel
2022-06-14 13:25 ` Rafael J. Wysocki
2022-04-11 19:00 ` [PATCH 16/20] ACPICA: iASL/MADT: Add OEM-defined subtable Rafael J. Wysocki
2022-04-11 19:01 ` [PATCH 17/20] ACPICA: executer/exsystem: Fix some typo mistakes Rafael J. Wysocki
2022-04-11 19:02 ` [PATCH 18/20] ACPICA: IORT: Updates for revision E.d Rafael J. Wysocki
2022-04-11 19:03 ` [PATCH 19/20] ACPICA: exsystem.c: Use ACPI_FORMAT_UINT64 for 64-bit output Rafael J. Wysocki
2022-04-11 19:04 ` [PATCH 20/20] ACPICA: Update version to 20220331 Rafael J. Wysocki
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=8110555.NyiUUSuA9g@kreacher \
--to=rjw@rjwysocki.net \
--cc=linux-acpi@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=robert.moore@intel.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -107,7 +107,7 @@ acpi_status acpi_ex_system_wait_mutex(ac
* FUNCTION: acpi_ex_system_do_stall
*
- * PARAMETERS: how_long - The amount of time to stall,
+ * PARAMETERS: how_long_us - The amount of time to stall,
* in microseconds
*
@@ -147,7 +147,7 @@ acpi_status acpi_ex_system_do_stall(u32
* FUNCTION: acpi_ex_system_do_sleep
*
- * PARAMETERS: how_long - The amount of time to sleep,
+ * PARAMETERS: how_long_ms - The amount of time to sleep,
* in milliseconds
*
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox